# Contributing to _Soomgo-gather_

Contributing 방법
------------

1. 버그레포팅

    a. 버그레포팅 전 체크리스트
    * document에서 기술한 제한된 기능인지 확인한다.
    * 이미 이슈로 생성된 버그인지 확인한다. [링크](https://github.com/Soomgo-Platform/soomgo-gather/issues)

    b.버그레포팅 작성 방법
    * [깃헙 이슈](https://github.com/Soomgo-Platform/soomgo-gather/issues) 를 통해 작성한다.
    * 가능한만큼 자세히 작성한다.

2. Pull Request(PR) 생성

    a. PR생성 전 체크리스트
    * feature 타입의 브랜치를 생성하여 새로운 작업을 진행한다. (브랜치명: feature/이슈번호)
    * isort(setup.cfg), black(pyproject.toml), flake8(setup.cfg)을 사용하여 코드컨벤션을 체크한다.
    * 테스트코드를 작성하고 pytest를 사용하여 테스트를 진행한다.

    b. PR생성 방법
    * master 브랜치를 타겟으로 PR을 생성한다.

Contributors
------------

Paul Cho, 2021/11/11

Rosa Kim, 2021/11/23